import pandas as pd#lecture du fichier csv
import matplotlib.pyplot as plt
import datetime#Gestion des dates
from datetime import timedelta

#Données csv issues de du portail IMCCE : https://ssp.imcce.fr/forms/ephemeris

annee=2022

tableau=pd.read_csv("EphemSoleil"+str(annee)+".csv", 
sep=';', #caractère de séparation des colonnes
skiprows=1, #ne pas lire la première ligne, car les noms des colonnes sont renommés 
usecols=[1, 4], 
names=['date', 'midi'], 
parse_dates=['date'], #reconnaître la colonne date comme des dates formatées
)

tableau=tableau.set_index('date')#réindexer le tableau avec les dates

midi=tableau['midi']
EDT=midi-12

plt.rcParams["font.family"] = "Ubuntu"#ou autre police installée
plt.rcParams["font.size"] = 10#à adapter aux dimensions des axes

def minsecondes(temps):#cette fonction transforme un temps décimal en écriture sexagésimale
    min=int(temps)
    secondes=abs(temps-min)*60
    return str(min) +" min " + str(round(secondes))+" s"#renvoie une chaîne de caractères

def minutes(temps):#arrondit à la minute
    return str(round(temps)) + " min."

fig, axs=plt.subplots(nrows=2, ncols=6, tight_layout=True)#création d'une figure et de 12 axes (1 par mois)
#Les graphes forment une grille de 2 lignes et 6 colonnes
#on peut modifier le nombre de grilles et colonnes, pourvu que le produit fasse 12.
axs=axs.flatten()#pour accéder à chaque graphe par axs[N]
fig.set_size_inches(21/2.54, 29.7/2.54)#dimensions de la figure, en pouces
#"""
#En modifiant les dimensions de la figure, il faudra peut-être ajuster :
#- la taille de la police
#- les limites des axes en x et en y
#Et réciproquement.

plt.suptitle("Équation du temps en %s"%(annee), fontsize=17, color='royalblue')

for N in range(1, 12+1):#N : numéro du mois courant, de 1 à 12
    ax=axs[N-1]
    date_debut=datetime.datetime(annee, N, 1)
    ax.set_title(date_debut.strftime("%B"), fontsize=13, c='blueviolet')#nom complet du mois
    ax.set_xticks([])#suppression des graduations
    ax.set_yticks([])#suppression des graduations
#    ax.axis('tight')
#    ax.axis('off')#efface les cadres des axes
    ax.set_ylim(-32, 0.5)#hauteur suffisante pour les listes de dates
    ax.set_xlim(-1.20, 50)#largeur suffisante pour le texte
    if N==12:
        date_fin=datetime.datetime(annee+1, 1, 1) - timedelta(days=1)#mois suivant moins 1 jour 
    else:
        date_fin=datetime.datetime(annee, N+1, 1) - timedelta(days=1)#mois suivant moins 1 jour 
    mois=tableau.loc[date_debut:date_fin]#filtrer le mois courant
    for jour in mois.index:
        Y=-float(jour.strftime('%d'))#numéro du jour, pris comme coordonnée verticale
        texte1=jour.strftime("%d %b")#N° du jours et nom abrégé du mois (nom complet : %B)
        EDT=float(mois.loc[jour, ['midi']]-12)*60#calcule le nombre de minutes décimales de l'équation du temps
        #pour la précision du résultat, choisir l'une des deux lignes suivantes :
        texte2=minsecondes(EDT)
#        texte2=minutes(EDT)
        ax.text(0, Y, texte1 +"    " +texte2, fontsize=8)#écriture des données

texte="Les calculs d’éphémérides de position des corps du Système solaire ont été réalisés par le service de calcul des éphémérides de l’IMCCE à travers son portail Système solaire (https://ssp.imcce.fr)"
fig.text(0.01, 0.005, texte, fontsize=6, ha='left', va='bottom')

NomFichier="EquationDuTemps_"+str(annee)
fig.savefig(NomFichier+".png", dpi=200)#création d'un fichier image PNG
fig.savefig(NomFichier+".pdf")#création d'un fichier PDF
plt.show()
